Documentation
¶
Overview ¶
`isr` package is the syntactic sugar of insyra.
Index ¶
- Variables
- func Name(value string) name
- func PtrDL[T *insyra.DataList | dl](l T) *dldeprecated
- func PtrDT[T *insyra.DataTable | dt](t T) *dtdeprecated
- func UseDL[T *insyra.DataList | dl](l T) *dl
- func UseDT[T *insyra.DataTable | dt](t T) *dt
- type CSV
- type CSV_inOpts
- type CSV_outOpts
- type Col
- type Cols
- type DLs
- type Excel
- type Excel_inOpts
- type JSON
- type Row
- type Rows
Constants ¶
This section is empty.
Variables ¶
var DL = dl{}
Use `DL.From` to create a new DataList from a slice or multiple elements of any type.
var DT = dt{}
Use `DT.From` to create a new DataTable from a DataList, DL, Row, Col, []Row, []Col, CSV, JSON, map[string]any, or map[int]any.
Functions ¶
Types ¶
type CSV ¶
type CSV struct {
FilePath string
String string
InputOpts CSV_inOpts
OutputOpts CSV_outOpts
}
type CSV_inOpts ¶
type CSV_outOpts ¶
type Col ¶
DL is a type alias for map[any]any. It is used to represent a column in a DataTable. Every key in the map represents a row Index.
type Excel ¶ added in v0.2.10
type Excel struct {
FilePath string
SheetName string
InputOpts Excel_inOpts
}
Excel represents a sheet in an Excel file.
type Excel_inOpts ¶ added in v0.2.10
Click to show internal directories.
Click to hide internal directories.